==> igniteui-angular-core-17.3.0.tgz: package/esm2015/lib/ChartSummaryDescriptionDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { ProvideCalculatorEventArgsDescriptionMetadata } from "./ProvideCalculatorEventArgsDescriptionMetadata";
import { ChartSummaryDescriptionDescription } from "./ChartSummaryDescriptionDescription";
/**
 * @hidden
 */
export let ChartSummaryDescriptionDescriptionMetadata = /*@__PURE__*/ (() => {
    class ChartSummaryDescriptionDescriptionMetadata extends Base {
        static b(a) {
            if (ChartSummaryDescriptionDescriptionMetadata.a == null) {
                ChartSummaryDescriptionDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                ChartSummaryDescriptionDescriptionMetadata.c(ChartSummaryDescriptionDescriptionMetadata.a);
            }
            if (a.k(ChartSummaryDescriptionDescriptionMetadata.a)) {
                return;
            }
            a.ab(ChartSummaryDescriptionDescriptionMetadata.a);
            ProvideCalculatorEventArgsDescriptionMetadata.d(a);
        }
        static c(a) {
            a.item("__marshalByValue", "Boolean");
            a.item("Field", "String");
            a.item("Operand", "ExportedType:string:DataSourceSummaryOperand");
            a.item("Operand@names", "Min;Max;Sum;Average;Count;Custom");
            a.item("Alias", "String");
            a.item("CalculatorDisplayName", "String");
            a.item("ProvideCalculatorRef", "EventRef::provideCalculator");
        }
        static d(a) {
            ChartSummaryDescriptionDescriptionMetadata.b(a);
            a.ad("ChartSummaryDescription", () => new ChartSummaryDescriptionDescription());
            a.ac("ChartSummaryDescription", ChartSummaryDescriptionDescriptionMetadata.a);
        }
    }
    ChartSummaryDescriptionDescriptionMetadata.$t = markType(ChartSummaryDescriptionDescriptionMetadata, 'ChartSummaryDescriptionDescriptionMetadata');
    ChartSummaryDescriptionDescriptionMetadata.a = null;
    return ChartSummaryDescriptionDescriptionMetadata;
})();

==> igniteui-angular-core-20.0.0.tgz: package/esm2015/lib/ChartSummaryDescriptionDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { ProvideCalculatorEventArgsDescriptionMetadata } from "./ProvideCalculatorEventArgsDescriptionMetadata";
import { ChartSummaryDescriptionDescription } from "./ChartSummaryDescriptionDescription";
/**
 * @hidden
 */
export let ChartSummaryDescriptionDescriptionMetadata = /*@__PURE__*/ (() => {
    class ChartSummaryDescriptionDescriptionMetadata extends Base {
        static b(a) {
            if (ChartSummaryDescriptionDescriptionMetadata.a == null) {
                ChartSummaryDescriptionDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                ChartSummaryDescriptionDescriptionMetadata.c(ChartSummaryDescriptionDescriptionMetadata.a);
            }
            if (a.k(ChartSummaryDescriptionDescriptionMetadata.a)) {
                return;
            }
            a.ac(ChartSummaryDescriptionDescriptionMetadata.a);
            ProvideCalculatorEventArgsDescriptionMetadata.d(a);
        }
        static c(a) {
            a.item("__marshalByValue", "Boolean");
            a.item("Field", "String");
            a.item("Operand", "ExportedType:string:DataSourceSummaryOperand");
            a.item("Operand@names", "Min;Max;Sum;Average;Count;Custom");
            a.item("Alias", "String");
            a.item("CalculatorDisplayName", "String");
            a.item("ProvideCalculatorRef", "EventRef::provideCalculator");
        }
        static d(a) {
            ChartSummaryDescriptionDescriptionMetadata.b(a);
            a.ae("ChartSummaryDescription", () => new ChartSummaryDescriptionDescription());
            a.ad("ChartSummaryDescription", ChartSummaryDescriptionDescriptionMetadata.a);
        }
    }
    ChartSummaryDescriptionDescriptionMetadata.$t = markType(ChartSummaryDescriptionDescriptionMetadata, 'ChartSummaryDescriptionDescriptionMetadata');
    ChartSummaryDescriptionDescriptionMetadata.a = null;
    return ChartSummaryDescriptionDescriptionMetadata;
})();
